@@ -1,5 +1,5 @@
-from PyObjCTools.TestSupport import *
 import IMServicePlugIn
+from PyObjCTools.TestSupport import TestCase, expectedFailure
 import objc
 
 
@@ -7,7 +7,3 @@ class TestIMServicePlugInFileTransfer(TestCase):
     @expectedFailure  # Class is likely part of the host application
     def testClasses(self):
         self.assertIsInstance(IMServicePlugIn.IMServicePlugInMessage, objc.objc_class)
-
-
-if __name__ == "__main__":
-    main()
